/*
 * Kosmos.
 *
 * Distributable under LGPL license.
 * See terms of license at gnu.org.
 */
package hu.midori.kosmos.model;

import java.util.Collection;
import java.util.Iterator;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * Utility methods for the domain model classes.
 *
 * @author <a href="mailto:aron.gombas@midori.hu">Aron Gombas</a>
 * @version $Id$
 */
public class ModelUtils {
    private static final Log log = LogFactory.getLog(ModelUtils.class);

    /** This class should never be instantiated. */
    protected ModelUtils() {
    }

    /** Millis in one hour. */
    public final static long MILLIS_PER_HOUR = 60*60*1000;
    /** Millis in one day. */
    public final static long MILLIS_PER_DAY = 24*MILLIS_PER_HOUR;
    /** Millis in one week. */
    public final static long MILLIS_PER_WEEK = 7*MILLIS_PER_DAY;
    /** Millis in one month (31 days). */
    public final static long MILLIS_PER_MONTH = 31*MILLIS_PER_DAY;

    /**
     * Returns the <code>Identified</code> object from a collection
     * by using a simple linear search, or <code>null</code> if not found.
     */
    public static Identified findInCollection(Collection<? extends Identified> items, int id) {
        Iterator<? extends Identified> it = items.iterator();
        while(it.hasNext()) {
            Identified item = it.next();
            if(item.getId() == id)
                return item;
        }

        return null;
    }
    /**
     * Returns the <code>Identified</code> object from a collection.
     * It receives the ID as String, so can be passed from request
     * params directly.
     *
     * @see #findInCollection(Collection, int)
     */
    public static Identified findInCollection(Collection<? extends Identified> items, String id) {
        int idInt = 0;

        try {
            idInt = Integer.parseInt(id);
        } catch(NumberFormatException ex) {
            log.error(ex);
            return null;
        }

        return findInCollection(items, idInt);
    }
}
